package appBaseTest;

import vfs.VFSDirectory;
import vfs.VFSFile;
import vfs.VFSVisitor;
import java.net.URL;
import java.util.ArrayList;
import java.util.List;
import java.util.Stack;
import mvc.CascadedChooser;
import mvc.Choice;
import mvc.LeafCascadedChooser;
import mvc.NonLeafCascadedChooser;

/**
 *
 * @author gshute
 */
public class ChooserBuilder
        implements VFSVisitor {

  private String name;
  private Stack<List<CascadedChooser<URL>>> listStack;
  private CascadedChooser<URL> chooser;

  private CascadedChooser<URL> createChooser(String nm,
          List<CascadedChooser<URL>> chooserList) {
    Choice<CascadedChooser<URL>> choice =
            new Choice<CascadedChooser<URL>>(chooserList);
    return new NonLeafCascadedChooser<URL>(nm, choice);
  }

  private ChooserBuilder() {
  }

  public ChooserBuilder(String nm) {
    name = nm;
    listStack = new Stack<List<CascadedChooser<URL>>>();
    listStack.push(new ArrayList<CascadedChooser<URL>>());
  }
  
  public void start() {
  }

  public void enter(VFSDirectory d) {
    listStack.push(new ArrayList<CascadedChooser<URL>>());
  }

  public void leave(VFSDirectory d) {
    List<CascadedChooser<URL>> chooserList = listStack.pop();
    listStack.peek().add(createChooser(d.getName(), chooserList));
  }

  public void visit(VFSFile f) {
    List<CascadedChooser<URL>> modelList = listStack.peek();
    String suffix = f.getSuffix();
    if (suffix.equals("htm") || suffix.equals("html") ||
            suffix.equals("txt")) {
      CascadedChooser<URL> leafChooser =
              new LeafCascadedChooser<URL>(f.getName(), f.getURL());
      modelList.add(leafChooser);
    }
  }

  public void finish() {
  }

  public CascadedChooser<URL> getChooser() {
    if (chooser == null) {
      chooser = createChooser(name, listStack.peek());
    }
    return chooser;
  }

}
