package guiTest;

import gui.AttachablePopupMenu;
import gui.DrawPanel;
import java.awt.BorderLayout;
import java.awt.Graphics2D;
import javax.swing.Action;
import javax.swing.JFrame;
import javax.swing.JMenu;
import javax.swing.JMenuBar;

/**
 *  This program tests and illustrates the use of the
 *  DrawPanel and AttachablePopupMenu classes.
 *  It also indirectly tests the ComponentPrintable
 *  class through the getPrintAction() method of
 *  DrawPanel.
 * 
 * @author gshute
 */
public class DrawPanelTest
        extends JFrame {

  /**
   *  This just displays a very simple fixed drawing.
   *  Most uses of DrawPanel should define a named
   *  class that extends DrawPanel.
   */
  public DrawPanelTest() {

    // Create a simple draw panel and add it to the
    // content pane.
    DrawPanel drawPanel = new DrawPanel() {

      protected void draw(Graphics2D g) {
        for (int i = 0; i < 5; i++) {
          for (int j = 0; j < 5; j++) {
            g.drawOval(40 * i, 40 * j, 40, 40);
          }
        }
      }

    };
    getContentPane().add(drawPanel, BorderLayout.CENTER);
    
    // Create a print action.
    Action printAction = drawPanel.getPrintAction();
    printAction.putValue(Action.SHORT_DESCRIPTION,
            "Print the draw panel");
    
    // Create a print action.
    Action exportAction = drawPanel.getExportAction();
    printAction.putValue(Action.SHORT_DESCRIPTION,
            "Export the draw panel");

    // Install a popup menu with the print and export actions.
    AttachablePopupMenu popupMenu =
            new AttachablePopupMenu();
    popupMenu.add(printAction);
    popupMenu.add(exportAction);
    popupMenu.attachTo(this);
    
    // Install a menu bar with the print  and export actions
    // in its "File" menu.
    JMenu fileMenu = new JMenu("File");
    fileMenu.add(printAction);
    fileMenu.add(exportAction);
    JMenuBar menuBar = new JMenuBar();
    menuBar.add(fileMenu);
    setJMenuBar(menuBar);
  }

  /**
   *  
   * @param args the command line arguments (ignored)
   */
  public static void main(String[] args) {
    JFrame frame = new DrawPanelTest();
    frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
    frame.pack();
    frame.setLocation(50, 50);
    frame.setVisible(true);
  }

}
