/*
 * ChooserTest.java
 *
 * Created on August 18, 2006, 10:31 AM
 *
 */
package mvcTest;

import java.awt.BorderLayout;
import java.awt.GridLayout;
import java.util.ArrayList;
import javax.swing.JFrame;
import javax.swing.JPanel;
import gui.Viewable;
import mvc.TabbedChooser;
import mvc.NamerView;
import mvc.ListChooser;
import mvc.ComboBoxChooser;
import mvc.CardView;
import gui.Wrapper;
import mvc.ViewableNamer;
import mvc.Callback;
import conversion.Named;
import conversion.NamedNamer;
import javax.swing.JComponent;
import mvc.Choice;

/**
 *  DOCME.
 *
 *  @author gshute
 */
public class ChooserTest
        extends JFrame {

  public JComponent createViewComponent() {

    // Create a list for string models.
    ArrayList<Choice.Model<String>> stringModels =
            new ArrayList<Choice.Model<String>>();

    // Create string choice 1 and model 1 and add model 1 to the model
    // list.
    String[] strings1 = new String[]{"ABC1", "DEF1", "GHI1", "JKL1"};
    Choice<String> stringChoice1 = new Choice<String>(strings1);
    stringModels.add(stringChoice1.createModel("Model 1"));

    // Create string choice 2 and model 2 and add model 2 to the model
    // list.
    String[] strings2 = new String[]{"ABC2", "DEF2", "GHI2", "JKL2"};
    Choice<String> stringChoice2 = new Choice<String>(strings2);
    stringModels.add(stringChoice2.createModel("Model 2"));

    // Create string choice 3 and model 3 and add model 3 to the model
    // list.
    String[] strings = new String[]{"ABC3", "DEF3", "GHI3", "JKL3"};
    Choice<String> stringChoice3 = new Choice<String>(strings);
    stringModels.add(stringChoice3.createModel("Model 3"));

    // Create a model choice and a model choice model.
    Choice<Choice.Model<String>> modelChoice =
            new Choice<Choice.Model<String>>(stringModels);
    final Choice.Model<Choice.Model<String>> modelChoiceModel =
            modelChoice.createModel("String Model Choice Model");

    // Create namer for string models.
    NamedNamer<Named> namer = new NamedNamer<Named>();

    // Create editor for model choice model.
    ComboBoxChooser<Named> modelChooser =
            new ComboBoxChooser<Named>(modelChoiceModel, namer);

    // Create combo box editor for string models.
    ComboBoxChooser<String> comboBoxStringChooser =
            new ComboBoxChooser<String>(modelChoice.getValue(0));
    comboBoxStringChooser.getViewComponent().setName("ComboBox");

    // Create list editor for string models.
    ListChooser<String> listStringChooser =
            new ListChooser<String>(modelChoice.getValue(0));
    listStringChooser.getViewComponent().setName("List");

    // Create tabbed editor for string models.
    TabbedChooser<String> tabbedStringChooser =
            new TabbedChooser<String>(modelChoice.getValue(0), 240);
    tabbedStringChooser.getViewComponent().setName("Tabbed");

    // Create choice for string model editors.
    ArrayList<Choice.Controller<String>> editors =
            new ArrayList<Choice.Controller<String>>();
    editors.add(tabbedStringChooser);
    editors.add(comboBoxStringChooser);
    editors.add(listStringChooser);
    Choice<Choice.Controller<String>> editorChoice =
            new Choice<Choice.Controller<String>>(editors);

    // Create an editor choice model.
    final Choice.Model<Choice.Controller<String>> editorChoiceModel =
            editorChoice.createModel("Editor Choice Model");

    // Create namer for string model editors.
    ViewableNamer editorNamer = new ViewableNamer();

    // Create a combo box chooser for the editor choice model.
    ComboBoxChooser<Viewable> editorChooser =
            new ComboBoxChooser<Viewable>(editorChoiceModel, editorNamer);
    editorChooser.getViewComponent().setName("Editor Chooser");

    // Create a callback to send a setModel() message to the currently
    // selected editor and register the callback with both the string model
    // choice model and the editor choice model.
    Callback callback = new Callback() {

      public void execute() {
        Choice.Controller<String> currentEditor = editorChoiceModel.getValue();
        Choice.Model<String> currentStringModel = modelChoiceModel.getValue();
        currentEditor.setModel(currentStringModel);
      }

    };
    modelChoiceModel.addCallback(callback);
    editorChoiceModel.addCallback(callback);

    // Organize the visual layout ---

    // Create a panel with the string model chooser and the editor chooser.
    JPanel chooserPanel = new JPanel(new GridLayout(2, 1));
    chooserPanel.add(Wrapper.titled(modelChooser, "Model Chooser"));
    chooserPanel.add(Wrapper.titled(editorChooser, "Editor Chooser"));

    // Create a card view for the editors.
    CardView<Viewable> editorView = new CardView<Viewable>(editorChoiceModel);

    // Create a panel with toString views for all of the string models.
    JPanel modelViewPanel = new JPanel(new GridLayout(3, 1));
    NamerView<String> model0View = new NamerView<String>(stringModels.get(0));
    modelViewPanel.add(Wrapper.named(model0View));
    NamerView<String> model1View = new NamerView<String>(stringModels.get(1));
    modelViewPanel.add(Wrapper.named(model1View));
    NamerView<String> model2View = new NamerView<String>(stringModels.get(2));
    modelViewPanel.add(Wrapper.named(model2View));

    // Create a derived editor model whose values are the editor wrapped in
    // buffer panels.

    // Wrap everything up in a top-level panel.
    final JPanel topLevelPanel = new JPanel(new BorderLayout());
    topLevelPanel.add(chooserPanel, BorderLayout.WEST);
    topLevelPanel.add(Wrapper.titled(editorView, "Editor"), BorderLayout.CENTER);
    topLevelPanel.add(modelViewPanel, BorderLayout.EAST);

    return topLevelPanel;
  }

  public ChooserTest() {
    setContentPane(createViewComponent());
    pack();
    setTitle("Chooser Test");
    setDefaultLookAndFeelDecorated(true);
    setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
  }

  public static void main(String[] args) {
    // Set up a frame for the top-level panel and show it.
    ChooserTest frame = new ChooserTest();
    frame.setLocation(50, 50);
    frame.setVisible(true);
  }

}  // public class ChooserTest
