/*
 * IntegralSliderTest.java
 *
 * Created on July 27, 2006, 9:13 PM
 *
 */
package mvcTest;

import java.awt.GridLayout;
import java.util.ArrayList;
import javax.swing.BoxLayout;
import javax.swing.JFrame;
import javax.swing.JPanel;
import mvc.NamerView;
import mvc.ComboBoxChooser;
import gui.Wrapper;
import mvc.IntegralSlider;
import mvc.Callback;
import conversion.Named;
import conversion.NamedNamer;
import mvc.Choice;
import mvc.IntegralRange;

/**
 *  DOCME.
 *
 *  @author gshute
 */
public class IntegralSliderTest {

  /**
   *  new IntegralSliderTest() returns a new IntegralSliderTest.
   */
  public IntegralSliderTest() {
  }  // public IntegralSliderTest()

  /**
   *  @param args the command line arguments
   */
  public static void main(String[] args) {

    // Create a model list.
    // It has an unchecked type so you can add different types of
    // number models.
    ArrayList<IntegralRange.Model> modelList =
            new ArrayList<IntegralRange.Model>();

    // Set up number ranges and models, adding the to the model list.

    // range1 and model1.
    IntegralRange range1 = new IntegralRange(100, 200);
    IntegralRange.Model model1 = range1.createModel("Model 1");
    modelList.add(model1);

    // range2 and model2.
    IntegralRange range2 = new IntegralRange(200, 300);
    IntegralRange.Model model2 = range2.createModel("Model 2");
    modelList.add(model2);

    // range3 and model3.
    IntegralRange range3 = new IntegralRange(300, 400);
    IntegralRange.Model model3 = range3.createModel("Model 3");
    modelList.add(model3);

    // range4 and model4.
    IntegralRange range4 = new IntegralRange(400, 500);
    IntegralRange.Model model4 = range4.createModel("Model 4");
    modelList.add(model4);

    // Create a number model multiple choice from the model list.
    Choice<IntegralRange.Model> modelChoice =
            new Choice<IntegralRange.Model>(modelList);

    // Create a model with choices from the multiple choice.
    final Choice.Model<IntegralRange.Model> modelChoiceModel =
            modelChoice.createModel("Model Choice Model");

    // Create a slider editor which is editing the initially selected number model.
    final IntegralSlider sliderEditor =
            new IntegralSlider(modelChoiceModel.getValue());
    sliderEditor.getViewComponent().setName("Slider Editor");

    // Create namer for number models.
    NamedNamer<Named> namer = new NamedNamer<Named>();

    // Create a combo box chooser for the number models.
    ComboBoxChooser<IntegralRange.Model> modelChooser =
            new ComboBoxChooser<IntegralRange.Model>(modelChoiceModel, namer);
    modelChooser.getViewComponent().setName("Model Chooser");

    // Create a panel containing toString views for each of the models.
    int modelCount = modelChoice.getValueCount();
    JPanel modelPanel = new JPanel(new GridLayout(1, modelCount));
    for (IntegralRange.Model model : modelChoice) {
      modelPanel.add(Wrapper.named(new NamerView<Integer>(model)));
    }

    // Now, the easy part: put together the user interface.
    JPanel topLevelPanel = new JPanel();
    topLevelPanel.setLayout(new BoxLayout(topLevelPanel, BoxLayout.Y_AXIS));
    topLevelPanel.add(Wrapper.named(sliderEditor));
    topLevelPanel.add(Wrapper.named(modelChooser));
    topLevelPanel.add(Wrapper.unwrapped(modelPanel));

    // Add a callback to the model choice model to set the model for the slider
    // editor and toString view.
    modelChoiceModel.addCallback(new Callback() {

      public void execute() {
        sliderEditor.setModel(modelChoiceModel.getValue());
      }

    });

    // And wrap it up in a frame.
    JFrame frame = new JFrame();
    frame.setContentPane(topLevelPanel);
    frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
    frame.setLocation(50, 50);
    frame.pack();
    frame.setTitle("Integer Slider Test");
    frame.setDefaultLookAndFeelDecorated(true);
    frame.setVisible(true);

  }

}  // public class IntegralSliderTest
