/*
 * RealSliderTest.java
 *
 * Created on August 8, 2006, 5:09 PM
 *
 */
package mvcTest;

import java.awt.GridLayout;
import java.util.ArrayList;
import javax.swing.BoxLayout;
import javax.swing.JFrame;
import javax.swing.JPanel;
import mvc.NamerView;
import mvc.ComboBoxChooser;
import gui.Wrapper;
import mvc.RealSlider;
import mvc.Callback;
import conversion.Named;
import conversion.NamedNamer;
import mvc.Choice;
import mvc.RealRange;

/**
 *  DOCME.
 *
 *  @author gshute
 */
public class RealSliderTest {

  /**
   *  new RealSliderTest() returns a new RealSliderTest.
   */
  public RealSliderTest() {
  }  // public RealSliderTest()

  /**
   *  @param args the command line arguments
   */
  public static void main(String[] args) {

    // Create a model list.
    // It has an unchecked type so you can add different types of
    // number models.
    ArrayList<RealRange.Model> modelList =
            new ArrayList<RealRange.Model>();

    // Set up number ranges and models, adding the to the model list.

    // range1 and model1.
    RealRange range1 = new RealRange(100.0, 200.0);
    RealRange.Model model1 = range1.createModel("Model 1");
    modelList.add(model1);

    // range2 and model2.
    RealRange range2 = new RealRange(200.0, 300.0);
    RealRange.Model model2 = range2.createModel("Model 2");
    modelList.add(model2);

    // range3 and model3.
    RealRange range3 = new RealRange(300.0, 400.0);
    RealRange.Model model3 = range3.createModel("Model 3");
    modelList.add(model3);

    // range4 and model4.
    RealRange range4 = new RealRange(400.0, 500.0);
    RealRange.Model model4 = range4.createModel("Model 4");
    modelList.add(model4);

    // Create a number model multiple choice from the model list.
    Choice<RealRange.Model> modelChoice =
            new Choice<RealRange.Model>(modelList);

    // Create a model with choices from the multiple choice.
    final Choice.Model<RealRange.Model> modelChoiceModel =
            modelChoice.createModel("Model Choice Model");

    // Create a slider editor which is editing the initially selected number model.
    final RealSlider sliderEditor =
            new RealSlider(modelChoiceModel.getValue());
    sliderEditor.getViewComponent().setName("Slider Editor");

    // Create namer for number models.
    NamedNamer<Named> namer = new NamedNamer<Named>();

    // Create a combo box chooser for the number models.
    ComboBoxChooser<RealRange.Model> modelChooser =
            new ComboBoxChooser<RealRange.Model>(modelChoiceModel, namer);
    modelChooser.getViewComponent().setName("Model Chooser");

    // Create a panel containing toString views for each of the models.
    int modelCount = modelChoice.getValueCount();
    JPanel modelPanel = new JPanel(new GridLayout(1, modelCount));
    for (RealRange.Model model : modelChoice) {
      modelPanel.add(Wrapper.named(new NamerView<Double>(model)));
    }

    // Now, the easy part: put together the user interface.
    JPanel topLevelPanel = new JPanel();
    topLevelPanel.setLayout(new BoxLayout(topLevelPanel, BoxLayout.Y_AXIS));
    topLevelPanel.add(Wrapper.named(sliderEditor));
    topLevelPanel.add(Wrapper.named(modelChooser));
    topLevelPanel.add(Wrapper.unwrapped(modelPanel));

    // Add a callback to the model choice model to set the model for the slider
    // editor and toString view.
    modelChoiceModel.addCallback(new Callback() {

      public void execute() {
        sliderEditor.setModel(modelChoiceModel.getValue());
      }

    });

    // And wrap it up in a frame.
    JFrame frame = new JFrame();
    frame.setContentPane(topLevelPanel);
    frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
    frame.setLocation(50, 50);
    frame.pack();
    frame.setTitle("Real Slider Test");
    frame.setDefaultLookAndFeelDecorated(true);
    frame.setVisible(true);

  }

}  // public class RealSliderTest
