/*
 * TabbedChooserTest.java
 *
 * Created on December 29, 2006, 7:19 AM
 *
 */
package mvcTest;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.GridLayout;
import java.util.ArrayList;
import javax.swing.JFrame;
import javax.swing.JPanel;
import mvc.Callback;
import mvc.Choice;
import mvc.ComboBoxChooser;
import conversion.Named;
import conversion.NamedNamer;
import mvc.NamerView;
import mvc.TabbedChooser;
import gui.Wrapper;

/**
 *  DOCME.
 *
 *  @author gshute
 */
public class TabbedChooserTest {

  /**
   *  new TabbedChooserTest() returns a new TabbedChooserTest.
   */
  public TabbedChooserTest() {
  }  // public TabbedChooserTest()

  public static void main(String[] args) {

    int width = 161;

    // Create a list for string models.
    ArrayList<Choice.Model<String>> stringModels =
            new ArrayList<Choice.Model<String>>();

    // Create string choice 1 and model 1 and add model 1 to the model
    // list.
    String[] strings1 = new String[]{
      "A1", "B1", "C1", "D1"
    };
    Choice<String> stringChoice1 = new Choice<String>(strings1);
    stringModels.add(stringChoice1.createModel("Model 1"));

    // Create string choice 2 and model 2 and add model 2 to the model
    // list.
    String[] strings2 = new String[]{
      "A2", "B2", "C2", "D2",
      "E2", "F2", "G2", "H2"
    };
    Choice<String> stringChoice2 = new Choice<String>(strings2);
    stringModels.add(stringChoice2.createModel("Model 2"));

    // Create string choice 3 and model 3 and add model 3 to the model
    // list.
    String[] strings3 = new String[]{
      "A3", "B3", "C3", "D3",
      "E3", "F3", "G3", "H3",
      "I3", "J3", "K3", "L3"
    };
    Choice<String> stringChoice3 = new Choice<String>(strings3);
    stringModels.add(stringChoice3.createModel("Model 3"));

    // Create string choice 4 and model 4 and add model 3 to the model
    // list.
    String[] strings4 = new String[]{
      "A4", "B4", "C4", "D4",
      "E4", "F4", "G4", "H4",
      "I4", "J4", "K4", "L4",
      "M4", "N4", "O4", "P4"
    };
    Choice<String> stringChoice4 = new Choice<String>(strings4);
    stringModels.add(stringChoice4.createModel("Model 4"));

    // Create a panel with toString views for all of the string models.
    JPanel modelViewPanel = new JPanel(new GridLayout(2, 2));
    NamerView<String> model0View = new NamerView<String>(stringModels.get(0));
    modelViewPanel.add(Wrapper.named(model0View));
    NamerView<String> model1View = new NamerView<String>(stringModels.get(1));
    modelViewPanel.add(Wrapper.named(model1View));
    NamerView<String> model2View = new NamerView<String>(stringModels.get(2));
    modelViewPanel.add(Wrapper.named(model2View));
    NamerView<String> model3View = new NamerView<String>(stringModels.get(3));
    modelViewPanel.add(Wrapper.named(model3View));

    // Create tabbed editor for the string models.
    final TabbedChooser<String> tabbedStringChooser =
            new TabbedChooser<String>(stringModels.get(0), width);
    tabbedStringChooser.getViewComponent().setName("Model Value Chooser");

    // Create a model choice and a model choice model.
    Choice<Choice.Model<String>> modelChoice =
            new Choice<Choice.Model<String>>(stringModels);
    final Choice.Model<Choice.Model<String>> modelChoiceModel =
            modelChoice.createModel("String Model Choice Model");

    // Create the namer for string models.
    NamedNamer<Named> namer = new NamedNamer<Named>();

    // Create the editor for the model choice model.
    ComboBoxChooser<Named> modelChooser =
            new ComboBoxChooser<Named>(modelChoiceModel, namer);

    // Create a chooser panel containing the tabbed chooser and the model panel.
    JPanel chooserPanel = new JPanel(new BorderLayout());
    chooserPanel.setPreferredSize(new Dimension(width, 200));
    chooserPanel.add(tabbedStringChooser.getViewComponent(),
            BorderLayout.NORTH);
    chooserPanel.add(modelViewPanel, BorderLayout.CENTER);

    // Create a top-level panel containing the model chooser and the chooser panel.
    JPanel topLevelPanel = new JPanel(new BorderLayout());
    topLevelPanel.add(Wrapper.paneled(modelChooser),
            BorderLayout.NORTH);
    topLevelPanel.add(chooserPanel, BorderLayout.CENTER);

    // Create a callback to send a setModel() message to the currently
    // selected editor and register the callback with both the string model
    // choice model and the editor choice model.
    Callback callback = new Callback() {

      public void execute() {
        Choice.Model<String> currentStringModel = modelChoiceModel.getValue();
        tabbedStringChooser.setModel(currentStringModel);
      }

    };
    modelChoiceModel.addCallback(callback);

    // Set up a frame for the top-level panel and show it.
    JFrame frame = new JFrame();
    frame.setContentPane(topLevelPanel);
    frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
    frame.setLocation(50, 50);
    frame.pack();
    frame.setTitle("TabbedChooser Test");
    frame.setDefaultLookAndFeelDecorated(true);
    frame.setVisible(true);
  }

}  // public class TabbedChooserTest
